- data
The data set used for analysis.
- sample.cov
covariance matrix for SEM analysis
when data are not available.
- sample.nobs
Number of observations for covariance matrix.
- model
The analytic model of interest.
- sens.model
Sensitivity analysis model template for
structural equation modeling
with a phantom variable. This is the model of interest
with a phantom variable and sensitivity parameters added.
See examples provided.
- opt.fun
Customized or preset optimization function.
The argument can be customized as a function, e.g., opt.fun =
quote(new.par$pvalue[paths]-old.par$pvalue[paths]), where new.par and old.par
are the parameter estimates from the sensitivity analysis and analytic models,
respectively.
When opt.fun is
1, the optimization function is the average departure of new estimate
from the old estimate divided by the old estimate
y <- mean(abs(new.par$est.std[paths] -
old.par$est.std[paths]))/mean(abs(old.par$est.std[paths])); When opt.fun is
2, the optimization function is the standard deviation of deviance
divided by the old estimate
y <- stats::sd(new.par$est.std[paths] - old.par$est.std[paths])/
mean(abs(old.par$est.std[paths]));
When opt.fun is 3, the optimization function is the average
p value changed or
y <- mean(abs(new.par$pvalue[paths] - old.par$pvalue[paths]));
When opt.fun is 4, the optimization function is the average distance
from significance level or y <- mean(abs(new.par$pvalue[paths] -
rep(sig.level,length(paths))));
When opt.fun is 5, we assess the change of RMSEA or
y <- abs(unname(lavaan::fitmeasures(new.out)["rmsea"]) -
unname(lavaan::fitmeasures(old.out)["rmsea"]));
When opt.fun is 6, we optimize how close RMSEA is to 0.05 or
y <- 1/abs(unname(lavaan::fitmeasures(new.out)["rmsea"]) - 0.05).
- d
Domains for initial sampling, default is c(-1 ,1) for all
sensitivity analysis parameters.
- paths
Paths in the model to be evaluated in a sensitivity analysis. If not
specified, all paths will be evaluated. It can be specified in a
numeric format or in a model format. For example, if we evaluate the changes (in p value
or parameter estimation) for paths in an analytic model, we may specify
paths in a model format, e.g.,
paths = 'm ~ x
y ~ x + m'.
Or, alternatively, as specify paths = c(1:3) if these paths present in line 1 to 3 in the
sensitivity analysis model results.
- verbose
Print out evaluation process if TRUE, default is TRUE.
- n.iter
Maximal number of function evaluations within each temperature.
- e
Maximum error value used when solution quality used as
the stopping criterion, default is 1e-10.
- k
Size of the solution archive, default is 100.
- sig.level
Significance level, default value is 0.05.
- Ntemps
Number of temperatures that the algorithm visits. Default value is 10.
- C.criteria
Convergence criterion. Default value is 1.
- steepness
Steepness of cooling schedule. Default value is 6.
- measurement
Logical. If TRUE, the argument paths will
include measurement paths in the lavaanify format. Default is FALSE.