A helper function that implements the main logic of tabu search to optimize objective functions in continuous domains.
sa.tabu.helper(
n.var,
f,
maximum = FALSE,
max.len = 1,
max.tabu.size = 5,
neigh.size = NULL,
max.iter = NULL,
max.iter.obj = NULL,
range = c(-1, 1),
r = 1e-05,
verbose = TRUE
)A list with three components: best.param (vector): the best set of parameters found; best.obj (scalar): the value of obj.fun corresponding to best.param; and model.history: the histry of model results.
The dimension of search space.
The objective function to be optimized.
Logical. Maximize the objective function if TRUE, minimize the objective function if FALSE.
The length of the largest hypercube.
The maximum size of the tabu list.
The number of neighbors to search for in each iteration.
The maximum number of iterations.
The maximum number of successive iterations without any improvement of the objective function value.
The range for the parameter space in the tabu search.
Radius of a tabu ball.
Logical. Print the current best and overall best objective functions if TRUE, no printing if FALSE.
P., & Berthiau, G. (1997). Fitting of tabu search to optimize functions of continuous variables. International journal for numerical methods in engineering, 40(13), 2449-2457.